#!/usr/bin/env perl
use WWW::Mechanize;   # libwww-mechanize-perl 
use LWP::UserAgent;   # libwww-perl
use File::Basename;   # perl-modules
use Digest::MD5 qw(md5 md5_hex md5_base64);

my $product = "ati-stream-sdk";
my $site_login_url='https://ssl-developer.amd.com/membership/Login.aspx';
my $site_product_url='http://developer.amd.com/gpu/ATIStreamSDK/Pages/default.aspx';
my $site_download_regex = qr/ati\-stream\-sdk\-v[0-9]+\.[0-9]+\-lnx64.tgz/;
my $savefilename = 'ati-stream-sdk-lnx64.tar.gz';

my $config_file="/etc/${product}-helper/${product}-site.conf";
my $release_file="/etc/${product}-helper/release";
my $release = "";
if ( -f "${product}-site.conf" ) {
    $config_file="${product}-site.conf";
    $release_file='release';
}

sub get_release()
{
    my $fd;
    open $fd,'<', $release_file or return("") ;
    my $rel = <$fd>;
    $rel =~ s/[^v0-9\.]//g;
    close($fd);
    return $rel;
}
$release = get_release();

sub config_site()
{
    my %config_hash = ( username=>'', password=>'', accept=>'no' );
    
    open my $fd,'<',$config_file or die ($config_file);
    while(<$fd>){
	chop($_);
	$_ =~ s/\#.*$//g;
	$_ =~ s/[\t\s]//g;
	my @parms = split (/=/,$_);
	if ( $#parms == 1 ){
	    $config_hash{$parms[0]}=$parms[1];
	}
    }
    close($fd);
    return %config_hash;
}

# read configurartion file
my %def=config_site();

# Licence Accept
exit(0) if ( $def{'accept'} =~ /^no$/i );

my $mech = WWW::Mechanize->new(agent=>"Get${product} 1.0",
			       cookie_jar => {});

# top
$mech->get( $site_login_url );
die($mech->res()->status_line() . ":" . "Login from.")
    unless ( $mech->res()->status_line() =~ /^200 OK/ );

my %hid = ();
foreach my $form ($mech->forms) {
    foreach my $input ($form->inputs) {
	$hid{$input->name} = $input->value ;
    }
}
if ( "" ne $ENV{"DEBUG"} ){
    foreach my $i  (sort(keys(%hid)))
    {
        print $i,"=",$hid{$i},"\n";
    }
}

$mech->submit_form(form_name => 'frmMain',
		   button    => 'loginView$amdLogin$btnSubmit',
		   fields    =>
		   { 'loginView$amdLogin$txtPassword'      =>
		     $def{'password'},
		     'loginView$amdLogin$txtUserName'      =>
		     $def{'username'},
		     'loginView$amdLogin$btnSubmit'        =>
		     $hid{'loginView$amdLogin$btnSubmit'},
		     'MSO_PageHashCode'                    =>
		     $hid{'MSO_PageHashCode'},
		     '__EVENTVALIDATION'		   => 
		     $hid{'__EVENTVALIDATION'},
		     '__VIEWSTATE'		   	   => 
		     $hid{'__VIEWSTATE'},
		   },
    );

die($mech->res()->status_line() . ":" . "Auth")
    unless ( $mech->res()->status_line() =~ /^200 OK/ );
die("There was an error with your username or password. see $config_file")
    unless ( $mech->content() =~ /Welcome/);

# Quick Link Product
$mech->get($site_product_url);

my $targeturl = '';
my $savefilename = '';
my $version = '';
foreach my $link ( $mech->find_all_links('url_regex' => $site_download_regex ))
{
    $targeturl= $link->url if $targeturl eq '';
}
$savefilename = $targeturl;
$savefilename =~ s#^.*/([^/]+)$#$1#;

$version = $savefilename;
$version =~ s#^.*(v[0-9]+\.[0-9]+).*$#$1#;

if ( "" ne $ENV{"DEBUG"} ){
    print "$targeturl\n";
    print "$savefilename\n";
    print "$version\n";
}


if ( $release eq $version ) {
    print $version,"\n";
    exit(0);
}

# result Here
$mech->follow_link('url_regex' => $site_download_regex);
die($mech->res()->status_line() . ":" . "Download")
    unless ( $mech->res()->status_line() =~ /^200 OK/ );

# agree onclick
my $dl_url = "";
foreach my $form ($mech->forms) {
    foreach my $input ($form->inputs) {
	if ( "btnAgreeLoginNotRequired" eq $input->name ){
	    $dl_url = $input->{onclick};
	    $dl_url =~ s/^window\.open\(\s*'([^']+)'(.*?)$/$1/;
        }
    }
}

$mech->get($dl_url) unless ( $dl_url eq "" );
die($mech->res()->status_line() . ":" . "Download")
    unless ( $mech->res()->status_line() =~ /^200 OK/ );

open my $fd,'>',$savefilename or die($savefilename);
print $fd $mech->content();
close $fd;
print $version,"\n";
exit(0);
